@@ -39,6 +39,30 @@ class Profile:
 		          `-\\)))
 
 		'''
+		self.art2 = '''
+
+
+  		 |\
+		  || \
+		  | | |
+		  /.,, /
+		 (    /
+		  \\  (
+		   \\ \
+		    \\_\\__
+		   .'    '--._    ,__,-.,
+		  /          _";__( ,__._7
+		 /           )  \\,=; \\
+		(         _.'     ~/  6,  '-,
+		 \\___    ;        (   _,-.  Y)
+		 (C(/\\.  )        /I-._\\_'-'
+		       \\\\,-,_  /,,/  '-7)
+		          \\  |"\\   \\  `
+		           \\ _\\ \\  \\__
+		            (`  \\ '.<,_)))  Bobby
+		          `-\\)))
+
+		'''
 
 	def Show_email(self):
 		if self.company != '':
@@ -49,6 +73,9 @@ class Profile:
 	def Show_myart(self):
 		print(self.art)
 
+	def Show_dog(self):
+		print(self.art2)
+
 	def Show_hobby(self):
 		if len(self.hobby) != 0:
 			print('---------my hobby--------')
@@ -66,6 +93,5 @@ if __name__ == '__main__':
 	my.Show_myart()
 	my.Show_email()
 	my.Show_hobby()
-	# help(my)
-	
-	
+	my.Show_dog()
+	# help(my)
\ No newline at end of file
